@@ -50,8 +50,14 @@ class Comparator(object):
         self.for_testing = for_testing
         self.errors = []
 
-    def compare_dirs(self, path_a, path_b, skip_missing=True, timestep=None):
-        logger.info('Comparing %s and %s [skip missing: %s]', path_a, path_b, str(skip_missing))
+    def compare_dirs(self, path_a, path_b, skip_missing=False, timestep=None):
+        """
+        :param path_a
+        :param path_b
+        :param skip_missing (bool, default False). If True, ignore files that are in path_a and not in path_b
+        :param timestep (default None). If passed, comparison happens only at the defined timestep
+        """
+        logger.info('Comparing %s and %s %s[skip missing: %s]', path_a, path_b, '(time: %s) ' % timestep if timestep else '', skip_missing)
         path_a = Path(path_a)
         path_b = Path(path_b)
         for fa in itertools.chain(*(path_a.glob(e) for e in self.glob_expr)):
@@ -100,6 +106,25 @@ class PCRComparator(Comparator):
             assert True
 
 
+def find_timestep(tss_file, timestep):
+    found_timestep = False
+    current_line = tss_file.readline()
+    while not found_timestep:
+        if not current_line:
+            break
+        try:
+            current_timestep = current_line.strip().split()[0]
+        except IndexError:
+            current_line = tss_file.readline()
+        else:
+            if current_timestep.decode() == str(timestep):
+                found_timestep = True
+                break
+            else:
+                current_line = tss_file.readline()
+    return current_line, found_timestep
+
+
 class TSSComparator(Comparator):
     glob_expr = ['**/*.tss']
 
@@ -110,15 +135,28 @@ class TSSComparator(Comparator):
         self.atol = atol
         self.rtol = rtol
 
-    def compare_lines_equal(self, file_a, file_b):
-        with open(file_a, 'rb') as fp1, open(file_b, 'rb') as fp2:
-            # skip first line in TSS as it just reports settings filename
-            fp1.readline()
-            fp2.readline()
+    def _findline_at_timestep(self, tss_file, timestep):
+        b1, found_timestep = find_timestep(tss_file, timestep)
+        if not found_timestep:
+            message = '{} not found in {}'.format(timestep, tss_file.name)
+            if self.for_testing:
+                assert False, message
+            else:
+                self.errors.append(message)
+        return b1
 
+    def compare_lines_equal(self, file_a, file_b, timestep=None):
+        tss1 = open(file_a, 'rb')
+        tss2 = open(file_b, 'rb')
+        # skip first line in TSS as it just reports settings filename
+        tss1.readline()
+        tss2.readline()
+
+        if not timestep:
+            # identical TSS files
             while True:
-                b1 = fp1.readline()
-                b2 = fp2.readline()
+                b1 = tss1.readline()
+                b2 = tss2.readline()
                 if (b1 != b2) or (not b1 and b2) or (not b2 and b1):
                     message = '{} different from {}'.format(file_a, file_b)
                     if self.for_testing:
@@ -128,42 +166,70 @@ class TSSComparator(Comparator):
                         return message
                 if not b1:
                     break
+        else:
+            # check line at a given timestep
+            b1 = self._findline_at_timestep(tss1, timestep)
+            b2 = self._findline_at_timestep(tss2, timestep)
 
-    def compare_lines_tolerance(self, file_a, file_b):
-        fp1 = open(file_a)
-        fp2 = open(file_b)
-        # skip first lines in TSS as it just reports settings filename
-        line = ''
-        numline = 1
-        while 'timestep' not in line:
-            fp1.readline()
-            line = fp2.readline()
-            numline += 1
-
-        while True:
-            b1 = fp1.readline().strip().split()
-            b2 = fp2.readline().strip().split()
-            if not b1:
-                break
-            array1 = np.array(b1, dtype='float64')
-            array2 = np.array(b2, dtype='float64')
-            if not np.allclose(array1, array2, rtol=self.rtol, atol=self.atol, equal_nan=True):
-                message = '{} different from {} (line: {})\n line A: {}\n line B: {}'.format(file_a, file_b, numline, array1, array2)
-                message += '\n {}'.format(np.abs(array1 - array2))
+            if b1 != b2:
+                message = '{} different from {} for timestep {}'.format(file_a, file_b, timestep)
                 if self.for_testing:
-                    np.testing.assert_allclose(array1, array2, rtol=self.rtol, atol=self.atol, equal_nan=True)
                     assert False, message
                 else:
                     self.errors.append(message)
         assert True
         return self.errors
 
+    def compare_lines_tolerance(self, file_a, file_b, timestep=None):
+        tss1 = open(file_a, 'rb')
+        tss2 = open(file_b, 'rb')
+        # skip first lines in TSS as it just reports settings filename
+        line = b''
+        numline = 1
+        while 'timestep' not in line.decode():
+            tss1.readline()
+            line = tss2.readline()
+            numline += 1
+
+        while True:
+            if not timestep:
+                b1 = tss1.readline().strip().split()
+                b2 = tss2.readline().strip().split()
+                if not b1:
+                    break
+                self._check_tss_line_tol(b1, b2, file_a, file_b, numline)
+            else:
+                b1 = self._findline_at_timestep(tss1, timestep)
+                b2 = self._findline_at_timestep(tss2, timestep)
+
+                b1 = b1.strip().split()
+                b2 = b2.strip().split()
+                self._check_tss_line_tol(b1, b2, file_a, file_b, numline)
+                # just one line
+                break
+
+        assert True
+        return self.errors
+
+    def _check_tss_line_tol(self, b1, b2, file_a, file_b, numline):
+        array1 = np.array(b1, dtype='float64')
+        array2 = np.array(b2, dtype='float64')
+        if not np.allclose(array1, array2, rtol=self.rtol, atol=self.atol, equal_nan=True):
+            message = '{} different from {} (line: {})\n line A: {}\n line B: {}'.format(file_a, file_b, numline,
+                                                                                         array1, array2)
+            message += '\n {}'.format(np.abs(array1 - array2))
+            if self.for_testing:
+                np.testing.assert_allclose(array1, array2, rtol=self.rtol, atol=self.atol, equal_nan=True)
+                assert False, message
+            else:
+                self.errors.append(message)
+
     def compare_files(self, file_a, file_b, timestep=None):
         logger.info('Comparing %s and %s', file_a, file_b)
         if self.array_equal:
-            self.compare_lines_equal(file_a, file_b)
+            self.compare_lines_equal(file_a, file_b, timestep)
         else:
-            self.compare_lines_tolerance(file_a, file_b)
+            self.compare_lines_tolerance(file_a, file_b, timestep)
 
 
 class NetCDFComparator(Comparator):
@@ -203,7 +269,8 @@ class NetCDFComparator(Comparator):
             perc_wrong = different_values_size * 100 / vara_step.size
             result = np.ma.where(diff_values >= max_diff)
             rel_diff = max_diff * 100. / np.maximum(vara_step[result], varb_step[result])
-            if rel_diff.size > 0 and np.max(rel_diff) > 0.01 and (perc_wrong >= self.max_perc_diff or (perc_wrong >= self.max_perc_large_diff and max_diff > self.large_diff_th)):
+            # if rel_diff.size > 0 and np.max(rel_diff) > 0.01 and (perc_wrong >= self.max_perc_diff or (perc_wrong >= self.max_perc_large_diff and max_diff > self.large_diff_th)):
+            if rel_diff.size > 0 and (perc_wrong >= self.max_perc_diff or (perc_wrong >= self.max_perc_large_diff and max_diff > self.large_diff_th)):
                 step = step if step is not None else '(no time)'
                 filepath = os.path.basename(filepath) if filepath else '<mem>'
                 varname = varname or '<unknown var>'
